#region Copyright  1997-2007 EPiServer AB. All Rights Reserved.
/*
This code may only be used according to the EPiServer License Agreement.
The use of this code outside the EPiServer environment, in whole or in
parts, is forbidden without prior written permission from EPiServer AB.

EPiServer is a registered trademark of EPiServer AB. For more information 
see http://www.episerver.com/license or request a copy of the EPiServer 
License Agreement by sending an email to info@episerver.com
*/
#endregion
using System;
using System.Collections.Generic;
using System.Text;
using System.Workflow.Activities;
using EPiServer.Core;

namespace CMS6Workflows.Workflows
{
    /// <summary>
    /// Argument to ApprovalEvent activity
    /// </summary>
    [Serializable]
    public class ApprovalEventArgs : ExternalDataEventArgs
    {
        private readonly string _message;
        private readonly string _approver;
        private readonly string _taskOwner;
        private readonly bool _approved;
        private readonly PageReference _pageLink;


        /// <summary>
        /// Initializes a new instance of the <see cref="ApprovalEventArgs"/> class.
        /// </summary>
        /// <param name="approved">if set to <c>true</c> the page is approved.</param>
        /// <param name="approver">The approver.</param>
        /// <param name="taskOwner">The task owner.</param>
        /// <param name="message">The message regarding the approval</param>
        /// <param name="workflowInstanceId">The workflow instance id.</param>
        /// <param name="pageLink">The page version to approve</param>
        public ApprovalEventArgs(bool approved, string approver, string taskOwner, string message, Guid workflowInstanceId, PageReference pageLink)
            : base(workflowInstanceId)
        {
            _message = message;
            _approved = approved;
            _approver = approver;
            _taskOwner = taskOwner;
            _pageLink = pageLink;
            this.WaitForIdle = true;
        }

        /// <summary>
        /// Gets the message from the approver
        /// </summary>
        /// <value>The message.</value>
        public string Message
        {
            get { return _message; }
        }

        /// <summary>
        /// Gets the name of the approver
        /// </summary>
        /// <value>The approver.</value>
        public string Approver
        {
            get { return _approver; }
        }

        /// <summary>
        /// Gets a value indicating whether this <see cref="ApprovalEventArgs"/> is approved.
        /// </summary>
        /// <value><c>true</c> if approved; otherwise, <c>false</c>.</value>
        public bool Approved
        {
            get { return _approved; }
        }

        /// <summary>
        /// Gets the name of the person/group the related task was assigned to.
        /// </summary>
        /// <value>The task owner.</value>
        public string TaskOwner
        {
            get { return _taskOwner; }
        }

        /// <summary>
        /// Gets the page link for the page version that this approval concerns
        /// </summary>
        /// <value>The page link.</value>
        public PageReference PageLink
        {
            get { return _pageLink; }
        }

    }
}
