#region Copyright  1997-2007 EPiServer AB. All Rights Reserved.
/*
This code may only be used according to the EPiServer License Agreement.
The use of this code outside the EPiServer environment, in whole or in
parts, is forbidden without prior written permission from EPiServer AB.

EPiServer is a registered trademark of EPiServer AB. For more information 
see http://www.episerver.com/license or request a copy of the EPiServer 
License Agreement by sending an email to info@episerver.com
*/
#endregion
using System;
using System.Collections.Generic;
using System.Text;

namespace CMS6Workflows.Workflows
{
    /// <summary>
    /// Represents an approver in an approval workflow
    /// </summary>
    [Serializable]
	public class ApproverItem
	{
        private string _approver;
        private bool _isRole;
        private bool _isRequired;

        /// <summary>
        /// Initializes a new instance of the <see cref="ApproverItem"/> class.
        /// </summary>
        /// <param name="approver">The approver.</param>
        /// <param name="isRole">if set to <c>true</c> [is role].</param>
        /// <param name="isRequired">if set to <c>true</c> [is required].</param>
        public ApproverItem(string approver, bool isRole, bool isRequired)
        {
            _approver = approver;
            _isRole = isRole;
            _isRequired = isRequired;
        }

        /// <summary>
        /// The name of the approver
        /// </summary>
        public string Approver
        {
            get { return _approver; }
        }

        /// <summary>
        /// Indicates if the approver is a user or role/group
        /// </summary>
        public bool IsRole
        {
            get { return _isRole; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this approver is required in the approval.
        /// </summary>
        /// <remarks>Only meaningful in parallel approval</remarks>
        /// <value>
        /// 	<c>true</c> if the approver is required; otherwise, <c>false</c>.
        /// </value>
        public bool IsRequired
        {
            get { return _isRequired; }
            set { _isRequired = value; }
        }
	}
}
