#region Copyright  1997-2007 EPiServer AB. All Rights Reserved.
/*
This code may only be used according to the EPiServer License Agreement.
The use of this code outside the EPiServer environment, in whole or in
parts, is forbidden without prior written permission from EPiServer AB.

EPiServer is a registered trademark of EPiServer AB. For more information 
see http://www.episerver.com/license or request a copy of the EPiServer 
License Agreement by sending an email to info@episerver.com
*/
#endregion
using System;
using System.Collections.Generic;
using System.Text;
using System.Workflow.Activities;
using EPiServer.Core;
using System.Collections.ObjectModel;

namespace CMS6Workflows.Workflows
{
    /// <summary>
    /// Arguments used with SetApproversEvent activity
    /// </summary>
    [Serializable]
    public class SetApproversEventArgs : ExternalDataEventArgs
    {
        private readonly string _taskDescription;
        private readonly List<ApproverItem> _approvers;
        private readonly PageReference _pageLink;
        private readonly int _neededApprovments;

        /// <summary>
        /// Initializes a new instance of the <see cref="SetApproversEventArgs"/> class.
        /// </summary>
        /// <param name="taskDescription">The task description.</param>
        /// <param name="approvers">The approvers.</param>
        /// <param name="neededApprovments">The needed approvments.</param>
        /// <param name="pageLink">The page version that is to be approved</param>
        /// <param name="workflowInstanceId">The workflow instance id.</param>
        public SetApproversEventArgs(
            string taskDescription,
            List<ApproverItem> approvers,
            int neededApprovments,
            PageReference pageLink, 
            Guid workflowInstanceId)
            : base(workflowInstanceId)
        {
            _taskDescription = taskDescription;
            _approvers = approvers;
            _neededApprovments = neededApprovments;
            _pageLink = pageLink;
            this.WaitForIdle = true;
        }

        /// <summary>
        /// Gets the task description.
        /// </summary>
        /// <value>The task description.</value>
        public string TaskDescription
        {
            get { return _taskDescription; }
        }

        /// <summary>
        /// Gets the approvers.
        /// </summary>
        /// <value>The approvers.</value>
        public List<ApproverItem> Approvers
        {
            get { return _approvers; }
        }

        /// <summary>
        /// Gets the page link for the page version to approve
        /// </summary>
        /// <value>The page link.</value>
        public PageReference PageLink
        {
            get { return _pageLink; }
        }

        /// <summary>
        /// Gets the minimum number of needed approvments.
        /// </summary>
        /// <value>The needed approvments.</value>
        /// <remarks>Only meaningful in parallel approval workflow</remarks>
        public int NeededApprovments
        {
            get { return _neededApprovments; }
        }
    }
}
