#region Copyright  1997-2007 EPiServer AB. All Rights Reserved.
/*
This code may only be used according to the EPiServer License Agreement.
The use of this code outside the EPiServer environment, in whole or in
parts, is forbidden without prior written permission from EPiServer AB.

EPiServer is a registered trademark of EPiServer AB. For more information 
see http://www.episerver.com/license or request a copy of the EPiServer 
License Agreement by sending an email to info@episerver.com
*/
#endregion
using System;
using System.Collections.Generic;
using System.Text;
using EPiServer.WorkflowFoundation.Interfaces;
using EPiServer.Personalization;
using EPiServer.Core;
using EPiServer.WorkflowFoundation.Activities;
using EPiServer.BaseLibrary;
using EPiServer.WorkflowFoundation;

namespace CMS6Workflows.Workflows
{
    /// <summary>
    /// Service registered with runtime. Used to track WorkflowTerminated event so it can cleanup.
    /// </summary>
    public class ReadyForTranslationService
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ReadyForTranslationService"/> class.
        /// </summary>
        public ReadyForTranslationService()
        {
            WorkflowSystem.WorkflowManager.PageRelatedEvent += new EventHandler<PageRelatedEventArgs>(WorkflowManager_PageRelatedEvent);
            WorkflowSystem.InstanceHandler.InstanceStarting += new EventHandler<StartInstanceEventArgs>(InstanceHandler_InstanceStarting);
            
            //make sure custom types are registerd with object store
            if (Context.Repository.SchemaForType(typeof(Workflows.TranslationItem)) == null)
            {
                Type type = typeof(Workflows.TranslationItem);
                EPiServer.Implementation.Serialization.TypeSchemaBuilder.RegisterSchemaAndType(type.ToString(), type);
            }
            if (Context.Repository.SchemaForType(typeof(List<Workflows.TranslationItem>)) == null)
            {
                Type type = typeof(List<Workflows.TranslationItem>);
                EPiServer.Implementation.Serialization.TypeSchemaBuilder.RegisterSchemaAndType(type.ToString(), type);
            }
        }

        /// <summary>
        /// Check if there already a instance running for this page, if so cancel starting
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void InstanceHandler_InstanceStarting(object sender, StartInstanceEventArgs e)
        {
            //early return if this instance is already cancelled
            if (e.Cancel)
            {
                return;
            }
            if (e.WorkflowDefinition.Type == typeof(ReadyForTranslation))
            {
                object pageArgsObj;
                if (e.NamedValueArgs.TryGetValue("PageArgs", out pageArgsObj) && pageArgsObj.GetType() == typeof(WorkflowPageEventArgs))
                {
                    WorkflowPageEventArgs pageArgs = (WorkflowPageEventArgs)pageArgsObj;
                    IList<WorkflowDefinitionInstance> instances = WorkflowSystem.InstanceHandler.GetInstances(pageArgs.PageLink, EPiServer.Security.AccessLevel.NoAccess);
                    foreach (WorkflowDefinitionInstance instance in instances)
                    {
                        //If there is already a ReadyForTranslation workflow running for this page stop this instance
                        if (instance.Type == typeof(ReadyForTranslation))
                        {
                            e.Cancel = true;
                            e.CancelReason = LanguageManager.Instance.Translate("/workflows/translate/cancelled");
                        }
                    }
                }
            }
        }

        //See if there is any translational workflow for the PageReference that is about to be deleted.
        //If so terminate them
        private void WorkflowManager_PageRelatedEvent(object sender, PageRelatedEventArgs e)
        {
            if (e.PageEvent == WorkflowPageEvent.PageDeleted)
            {
                IList<WorkflowDefinitionInstance> instances = WorkflowSystem.InstanceHandler.GetInstances(e.PageEventArgs.PageLink);
                foreach (WorkflowDefinitionInstance instance in instances)
                {
                    if (instance.Type == typeof(ReadyForTranslation))
                    {
                        EPiServer.WorkflowFoundation.Utility.DeleteTasksForInstance(instance.InstanceId);
                        WorkflowSystem.InstanceHandler.TerminateInstance(instance.InstanceId, "page deleted");
                    }
                }
            }

        }

    }
}
