#region Copyright  1997-2007 EPiServer AB. All Rights Reserved.
/*
This code may only be used according to the EPiServer License Agreement.
The use of this code outside the EPiServer environment, in whole or in
parts, is forbidden without prior written permission from EPiServer AB.

EPiServer is a registered trademark of EPiServer AB. For more information 
see http://www.episerver.com/license or request a copy of the EPiServer 
License Agreement by sending an email to info@episerver.com
*/
#endregion
using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using EPiServer.WorkflowFoundation.UI;
using System.Collections.Generic;
using EPiServer.Web.PageExtensions;
using EPiServer.Core;
using EPiServer.Personalization;
using EPiServer.WorkflowFoundation.Activities;
using EPiServer.WorkflowFoundation;

namespace CMS6Workflows.Workflows
{
    /// <summary>
    /// Control that is loaded when owner of RequestForFeedback workflow clicks his/her task
    /// </summary>
    public partial class WorkflowFeedbackOwner : System.Web.UI.UserControl, IWorkflowTaskControl
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            History.DataBind();
        }


        #region IWorkflowTaskControl Members

        /// <summary>
        /// Will be called at startup of the control to sets the context for the task.
        /// </summary>
        /// <param name="workflowInstanceId">The workflow instance id.</param>
        /// <param name="taskId">The task id.</param>
        /// <param name="eventQualifiedName">The Qualified name of the event activity that specified usercontrol</param>
        /// <param name="pageLink">The page that is currently loaded in beside action window</param>
        public void ContextData(Guid workflowInstanceId, int taskId, string eventQualifiedName, PageReference pageLink)
        {
            Task task = Task.Load(taskId);
            History.WorkflowInstanceId = workflowInstanceId;
            History.AccessLevel = EPiServer.Security.AccessLevel.NoAccess;
            RequestDescription.Text = task.Description;
        }

        /// <summary>
        /// Gets the text the invoke button should have. 
        /// If null or string.Empty is returned, default text "Send" (language dependent) is used
        /// We set value to "Complete workflow" (language dependent)
        /// </summary>
        /// <value>The invoke button text.</value>
        public string InvokeButtonText
        {
            get { return LanguageManager.Instance.Translate("/workflows/feedbackrequest/finish"); }
        }

        /// <summary>
        /// Method that is called when user clicks "Send" button. We just terminate workflow instance. 
        /// The RequestForFeedbackService has an event handler for WorkflowTerminated which will clean up 
        /// all tasks for this instance.
        /// </summary>
        /// <param name="workflowInstanceId">workflow instance</param>
        /// <param name="taskId">id of related task</param>
        /// <param name="eventQualifiedName">The Qualified name of the event activity that specified usercontrol</param>
        /// <returns>true if task should be deleted, else false</returns>
        /// <remarks>Before InvokeEvent are called Page.IsValid() is called so any custom validators will have chance to validate input</remarks>
        public bool InvokeEvent(Guid workflowInstanceId, int taskId, string eventQualifiedName)
        {
            if (WorkflowSystem.InstanceHandler.ContainsInstance(workflowInstanceId))
            {
                WorkflowSystem.InstanceHandler.TerminateInstance(workflowInstanceId, "owner request", EPiServer.Security.AccessLevel.NoAccess);
            }

            return true;
        }

        /// <summary>
        /// We dont bother
        /// </summary>
        /// <param name="previousPageLink">The previous page link.</param>
        /// <param name="newPageLink">The new page link.</param>
        public void PageHasChanged(PageReference previousPageLink, PageReference newPageLink)
        {
        }

        #endregion

      


       
    }
}