#region Copyright  1997-2007 EPiServer AB. All Rights Reserved.
/*
This code may only be used according to the EPiServer License Agreement.
The use of this code outside the EPiServer environment, in whole or in
parts, is forbidden without prior written permission from EPiServer AB.

EPiServer is a registered trademark of EPiServer AB. For more information 
see http://www.episerver.com/license or request a copy of the EPiServer 
License Agreement by sending an email to info@episerver.com
*/
#endregion
using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using EPiServer.WorkflowFoundation.UI;
using System.Collections.Generic;
using EPiServer.Web.PageExtensions;
using EPiServer.Core;
using EPiServer.Personalization;
using EPiServer.WorkflowFoundation.Activities;
using EPiServer.DataAbstraction;
using EPiServer.WorkflowFoundation;

namespace CMS6Workflows.Workflows
{
    /// <summary>
    /// Control that is loaded for user who have get an task with feedback request
    /// </summary>
    public partial class WorkflowFeedbackUser : System.Web.UI.UserControl, IWorkflowTaskControl
    {
        /// <summary>
        /// Handles the Load event of the User Control.
        /// </summary>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            History.DataBind();
        }

        #region IWorkflowTaskControl Members
        /// <summary>
        /// Will be called at startup of the control to sets the context for the task. Initialize controls
        /// </summary>
        /// <param name="workflowInstanceId">The workflow instance id.</param>
        /// <param name="taskId">The task id.</param>
        /// <param name="eventQualifiedName">The Qualified name of the event activity that specified usercontrol</param>
        /// <param name="pageLink">The page that is currently loaded in beside action window</param>
        public void ContextData(Guid workflowInstanceId, int taskId, string eventQualifiedName, PageReference pageLink)
        {
            Task task = Task.Load(taskId);
            History.WorkflowInstanceId = workflowInstanceId;
            History.AccessLevel = EPiServer.Security.AccessLevel.NoAccess;
            RequestDescription.Text = task.Description;
        }

        /// <summary>
        /// Gets the text the invoke button should have. 
        /// If null or string.Empty is returned, default text "Send" (language dependent) is used
        /// For this contorl we set "Post" (language dependent)
        /// </summary>
        /// <value>The invoke button text.</value>
        public string InvokeButtonText
        {
            get { return LanguageManager.Instance.Translate("/workflows/feedbackrequest/post"); }
        }

        /// <summary>
        /// Method that is called when user clicks "Send" button. Can e.g. be used to invoke event on custom service
        /// We add a history item with the feedback to the instance and then updates Owners task.
        /// </summary>
        /// <param name="workflowInstanceId">workflow instance</param>
        /// <param name="taskId">id of related task</param>
        /// <param name="eventQualifiedName">The Qualified name of the event activity that specified usercontrol</param>
        /// <returns>true if task should be deleted, else false</returns>
        /// <remarks>Before InvokeEvent are called Page.IsValid() is called so any custom validators will have chance to validate input</remarks>
        public bool InvokeEvent(Guid workflowInstanceId, int taskId, string eventQualifiedName)
        {
            //Pick up current user
            string currentUser = (System.Web.HttpContext.Current != null && EPiServer.Security.PrincipalInfo.Current != null) ?
                    EPiServer.Security.PrincipalInfo.Current.Name : string.Empty;

            //Update instance wtih feedaback
            WorkflowDefinitionInstance instance = WorkflowSystem.InstanceHandler.GetInstance(
                workflowInstanceId,
                EPiServer.Security.AccessLevel.NoAccess);
            instance.AddHistoryItem(new HistoryItem(
                "/workflows/feedbackrequest/feedbackposted",
                Message.Text,
                currentUser));
            WorkflowSystem.InstanceHandler.SaveInstance(instance, EPiServer.Security.AccessLevel.NoAccess);

            //Update owner task
            IList<Task> tasks = WorkflowSystem.InstanceHandler.GetTasks(workflowInstanceId);
            foreach (Task task in tasks)
            {
                if (task.StateBag.Contains("Owner") && (bool)task.StateBag["Owner"] == true)
                {
                    task.Subject = ApprovalBase.Translate(task.AssignedTo, "/workflows/feedbackrequest/feedbackposted");
                    task.Save(true);
                    break;
                }
            }

            //return true so task is deleted
            return true;
        }

        /// <summary>
        /// We dont bother
        /// </summary>
        /// <param name="previousPageLink">The previous page link.</param>
        /// <param name="newPageLink">The new page link.</param>
        public void PageHasChanged(PageReference previousPageLink, PageReference newPageLink)
        {
        }
        #endregion
    }
}